pub struct ProcessedInfo {
pub hash: AssetHash,
pub full_hash: AssetHash,
pub process_dependencies: Vec<ProcessDependencyInfo>,
}Expand description
Info produced by the AssetProcessor for a given processed asset. This is used to determine if an
asset source file (or its dependencies) has changed.
Fields
hash: AssetHashA hash of the asset bytes and the asset .meta data
full_hash: AssetHashA hash of the asset bytes, the asset .meta data, and the full_hash of every process_dependency
process_dependencies: Vec<ProcessDependencyInfo>Information about the “process dependencies” used to process this asset.